This example shows how to use inline forms when working with related models.

To run this example:

1. Clone the repository::

    git clone https://github.com/flask-admin/flask-admin.git
    cd flask-admin

2. Create and activate a virtual environment::

    virtualenv env
    source env/bin/activate

3. Install requirements::

    pip install -r 'examples/sqla-custom-inline-forms/requirements.txt'

4. Run the application::

    python examples/sqla-custom-inline-forms/app.py
